@@ -46,12 +46,14 @@ class APIError(requests.exceptions.HTTPError, DockerException):
         message = super(APIError, self).__str__()
 
         if self.is_client_error():
-            message = '{0} Client Error: {1}'.format(
-                self.response.status_code, self.response.reason)
+            message = '{0} Client Error for {1}: {2}'.format(
+                self.response.status_code, self.response.url,
+                self.response.reason)
 
         elif self.is_server_error():
-            message = '{0} Server Error: {1}'.format(
-                self.response.status_code, self.response.reason)
+            message = '{0} Server Error for {1}: {2}'.format(
+                self.response.status_code, self.response.url,
+                self.response.reason)
 
         if self.explanation:
             message = '{0} ("{1}")'.format(message, self.explanation)
@@ -163,3 +165,35 @@ def create_unexpected_kwargs_error(name, kwargs):
         text.append("got unexpected keyword arguments ")
     text.append(', '.join(quoted_kwargs))
     return TypeError(''.join(text))
+
+
+class MissingContextParameter(DockerException):
+    def __init__(self, param):
+        self.param = param
+
+    def __str__(self):
+        return ("missing parameter: {}".format(self.param))
+
+
+class ContextAlreadyExists(DockerException):
+    def __init__(self, name):
+        self.name = name
+
+    def __str__(self):
+        return ("context {} already exists".format(self.name))
+
+
+class ContextException(DockerException):
+    def __init__(self, msg):
+        self.msg = msg
+
+    def __str__(self):
+        return (self.msg)
+
+
+class ContextNotFound(DockerException):
+    def __init__(self, name):
+        self.name = name
+
+    def __str__(self):
+        return ("context '{}' not found".format(self.name))
